@@ -514,10 +514,11 @@ class Human:
         if 'ankle' not in ai_crop_point_dict.keys() and 'human_bottom' in ai_crop_point_dict.keys():
             ai_crop_point_dict.pop('human_bottom')
 
-        # 先修改头顶的逻辑，暂时没时间测脚底的
-        top_padding = ai_crop_point_dict['human_top']['top_site'][1] * self.image_height
-        if top_padding < 5:
-            ai_crop_point_dict.pop('human_top')
+        if 'human_top' in ai_crop_point_dict.keys():
+            # 先修改头顶的逻辑，暂时没时间测脚底的
+            top_padding = ai_crop_point_dict['human_top']['top_site'][1] * self.image_height
+            if top_padding < 5:
+                ai_crop_point_dict.pop('human_top')
 
         # bottom_padding = (1 - ai_crop_point_dict['human_bottom']['bottom_site'][1]) * self.image_height
         # if bottom_padding < 5:
@@ -1068,7 +1069,7 @@ class Shoes:
             for one_shoes in shoes_info['clothes']:
                 if one_shoes['confidence'] < self.threshold:  # 置信度过低
                     continue
-                if one_shoes['category_id'] != 8:  # 类型不是鞋子
+                if one_shoes['category_id'] != 6:  # 类型不是鞋子
                     continue
                 shoes = self.deal_shoes(one_shoes)
                 shoes_list.append(shoes)
@@ -1106,6 +1107,16 @@ class Shoes:
 
         for shoes in self.shoes_list:
             crop_point_dict = self.shoes_crop_point(shoes, crop_point_dict)
+
+        crop_point_dict['shoes_top'] = {
+            'top_site': crop_point_dict['shoes_top']['top_site'],
+            "bottom_site": crop_point_dict['shoes_top']['top_site']
+        }
+        crop_point_dict['shoes_bottom'] = {
+            'top_site': crop_point_dict['shoes_bottom']['bottom_site'],
+            "bottom_site": crop_point_dict['shoes_bottom']['bottom_site']
+        }
+
         return crop_point_dict
 
     def shoes_crop_point(self, shoes, crop_point_dict):
