@@ -424,7 +424,7 @@ class ImageCrop:
             self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
         elif crop_method == 'e':  # 扩边裁剪，slot高不变,宽可以改变
             crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height = self.__extension_crop(
-                expand_y1, expand_y2, {'x1': x1, 'x2': x2}, [slot_width, slot_height], img
+                top, bottom, {'x1': x1, 'x2': x2}, [slot_width, slot_height, crop_parameter.get(TOP, 0), crop_parameter.get(BOTTOM, 0)], img
             )
 
         else:  # 固定裁剪, slot宽高不变
@@ -601,7 +601,7 @@ class ImageCrop:
             return crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height, img.width, img.height
         elif crop_method == 'e':  # 扩边裁剪
             crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height = self.__extension_crop(
-                0, 1, {'x1': 0, 'x2': 1}, [slot_width, slot_height], img
+                0, 1, {'x1': 0, 'x2': 1}, [slot_width, slot_height, 0, 0], img
             )
             return crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height, img.width, img.height
         else:
@@ -609,10 +609,12 @@ class ImageCrop:
 
     def __extension_crop(self, top, bottom, crop_point_result_dict, origin_slot, img):
         # 一定要考虑图片放缩 后 相关点的变化
-
-        origin_slot_width, origin_slot_height = origin_slot
+        origin_slot_width, origin_slot_height,top_padding, bottom_padding = origin_slot
+        no_padding_slot_height = origin_slot_height - top_padding - bottom_padding
+        if no_padding_slot_height <=0:
+            raise ValueError(f"扩边裁剪，上下边距之和超过图片尺寸{origin_slot_height}")
         # 裁剪高铺满的情况下,等比放缩 裁剪 宽
-        height_scale = origin_slot_height / ((bottom - top) * img.height)
+        height_scale = no_padding_slot_height / ((bottom - top) * img.height)
         transform_img_width = img.width * height_scale
 
         scale_x = scale_y = height_scale
@@ -654,7 +656,7 @@ class ImageCrop:
         self.si.main_part_offset(x * img.width + origin_slot_width / scale_x / 2, center * img.width, 'x')
 
         self.si.img_scale_ratio(scale_x, scale_y)
-        return x * img.width, y * img.height, origin_slot_width / scale_x, origin_slot_height / scale_x, scale_x, scale_y, 0
+        return x * img.width, y * img.height - top_padding/height_scale, origin_slot_width / scale_x, origin_slot_height / scale_x, scale_x, scale_y, 0
 
     def __gif_crop(self, slot_width, slot_height, img):
         """动图宽固定，高自适应 计算出 裁剪参数"""
